# SwaggerClient-php
Daily and hourly historical weather data for latitude/longitude points, Zip/Postal Codes, Designated Market Areas, and OnPoint™ points. The Weather Source History API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.  An API key is required to authorize requests. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/).

This PHP package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Build package: io.swagger.codegen.v3.generators.php.PhpClientCodegen
For more information, please visit [https://developer.weathersourceapis.com/](https://developer.weathersourceapis.com/)

## Requirements

PHP 5.5 and later

## Installation & Usage
### Composer

To install the bindings via [Composer](http://getcomposer.org/), add the following to `composer.json`:

```
{
  "repositories": [
    {
      "type": "git",
      "url": "https://github.com/GIT_USER_ID/GIT_REPO_ID.git"
    }
  ],
  "require": {
    "GIT_USER_ID/GIT_REPO_ID": "*@dev"
  }
}
```

Then run `composer install`

### Manual Installation

Download the files and include `autoload.php`:

```php
    require_once('/path/to/SwaggerClient-php/vendor/autoload.php');
```

## Tests

To run the unit tests:

```
composer install
./vendor/bin/phpunit
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```php
<?php
require_once(__DIR__ . '/vendor/autoload.php');

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$date = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, presTend, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdDaysDateGet($dma_id, $date, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdDaysDateGet: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$date_start = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
$date_end = new \DateTime("2013-10-20"); // \DateTime | An date formatted as a RFC3339 date value that must occur temporally after dateStart.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, presTend, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdDaysDateStartdateEndGet($dma_id, $date_start, $date_end, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdDaysDateStartdateEndGet: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$timestamp = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, snowfall)* * allPres *(mslPres, presTend, sfcPres)* * allRad *(radSolar)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdHoursTimestampGet($dma_id, $timestamp, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdHoursTimestampGet: ', $e->getMessage(), PHP_EOL;
}

// Configure API key authorization: ApiKeyAuth
$config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKey('X-API-KEY', 'YOUR_API_KEY');
// Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
// $config = Swagger\Client\Configuration::getDefaultConfiguration()->setApiKeyPrefix('X-API-KEY', 'Bearer');

$apiInstance = new Swagger\Client\Api\DmasApi(
    // If you want use custom http client, pass your client which implements `GuzzleHttp\ClientInterface`.
    // This is optional, `GuzzleHttp\Client` will be used as default.
    new GuzzleHttp\Client(),
    $config
);
$dma_id = 56; // int | A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
$timestamp_start = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
$timestamp_end = new \DateTime("2013-10-20T19:20:30+01:00"); // \DateTime | A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
$fields = array("fields_example"); // string[] | A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(cldCvr)* * allHum *(relHum, spcHum)* * allPrecip *(precip, snowfall)* * allPres *(mslPres, presTend, sfcPres)* * allRad *(radSolar)* * allTemp *(dewPt, feelsLike, heatIndex, temp, wetBulb, windChill)* * allWind *(windDir, windDir80m, windDir100m, windSpd, windSpd80m, windSpd100m)* * popular *(cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)*
$unit_scale = "IMPERIAL"; // string | The unit scale for returned values.<br>

try {
    $result = $apiInstance->dmasDmaIdHoursTimestampStarttimestampEndGet($dma_id, $timestamp_start, $timestamp_end, $fields, $unit_scale);
    print_r($result);
} catch (Exception $e) {
    echo 'Exception when calling DmasApi->dmasDmaIdHoursTimestampStarttimestampEndGet: ', $e->getMessage(), PHP_EOL;
}
?>
```

## Documentation for API Endpoints

All URIs are relative to *https://history.weathersourceapis.com/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DmasApi* | [**dmasDmaIdDaysDateGet**](docs/Api/DmasApi.md#dmasdmaiddaysdateget) | **GET** /dmas/{dmaId}/days/{date} | A day of weather history for a DMA.
*DmasApi* | [**dmasDmaIdDaysDateStartdateEndGet**](docs/Api/DmasApi.md#dmasdmaiddaysdatestartdateendget) | **GET** /dmas/{dmaId}/days/{dateStart},{dateEnd} | A contiguous range of daily weather history for a DMA.
*DmasApi* | [**dmasDmaIdHoursTimestampGet**](docs/Api/DmasApi.md#dmasdmaidhourstimestampget) | **GET** /dmas/{dmaId}/hours/{timestamp} | An hour of weather history for a DMA
*DmasApi* | [**dmasDmaIdHoursTimestampStarttimestampEndGet**](docs/Api/DmasApi.md#dmasdmaidhourstimestampstarttimestampendget) | **GET** /dmas/{dmaId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly weather history for a DMA.
*OnpointsApi* | [**onpointsOnpointIdDaysDateGet**](docs/Api/OnpointsApi.md#onpointsonpointiddaysdateget) | **GET** /onpoints/{onpointId}/days/{date} | A day of weather history for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdDaysDateStartdateEndGet**](docs/Api/OnpointsApi.md#onpointsonpointiddaysdatestartdateendget) | **GET** /onpoints/{onpointId}/days/{dateStart},{dateEnd} | A contiguous range of daily weather history for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdHoursTimestampGet**](docs/Api/OnpointsApi.md#onpointsonpointidhourstimestampget) | **GET** /onpoints/{onpointId}/hours/{timestamp} | An hour of weather history for an OnPoint™ point.
*OnpointsApi* | [**onpointsOnpointIdHoursTimestampStarttimestampEndGet**](docs/Api/OnpointsApi.md#onpointsonpointidhourstimestampstarttimestampendget) | **GET** /onpoints/{onpointId}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly weather history for an OnPoint™ point.
*PointsApi* | [**pointsLatitudelongitudeDaysDateGet**](docs/Api/PointsApi.md#pointslatitudelongitudedaysdateget) | **GET** /points/{latitude},{longitude}/days/{date} | A day of weather history for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeDaysDateStartdateEndGet**](docs/Api/PointsApi.md#pointslatitudelongitudedaysdatestartdateendget) | **GET** /points/{latitude},{longitude}/days/{dateStart},{dateEnd} | A contiguous range of daily weather history for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHoursTimestampGet**](docs/Api/PointsApi.md#pointslatitudelongitudehourstimestampget) | **GET** /points/{latitude},{longitude}/hours/{timestamp} | An hour of weather history for a Latitude/Longitude point.
*PointsApi* | [**pointsLatitudelongitudeHoursTimestampStarttimestampEndGet**](docs/Api/PointsApi.md#pointslatitudelongitudehourstimestampstarttimestampendget) | **GET** /points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly weather history for a Latitude/Longitude point.
*PostcodesApi* | [**postcodesPostcodecountryCodeDaysDateGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodedaysdateget) | **GET** /postcodes/{postcode},{countryCode}/days/{date} | A day of weather history for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeDaysDateStartdateEndGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodedaysdatestartdateendget) | **GET** /postcodes/{postcode},{countryCode}/days/{dateStart},{dateEnd} | A contiguous range of daily weather history for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeHoursTimestampGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodehourstimestampget) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestamp} | An hour of weather history for a postcode.
*PostcodesApi* | [**postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet**](docs/Api/PostcodesApi.md#postcodespostcodecountrycodehourstimestampstarttimestampendget) | **GET** /postcodes/{postcode},{countryCode}/hours/{timestampStart},{timestampEnd} | A contiguous range of hourly weather history for a postcode.

## Documentation For Models

 - [BoundingPoints](docs/Model/BoundingPoints.md)
 - [BoundingPointsInner](docs/Model/BoundingPointsInner.md)
 - [CldCvr](docs/Model/CldCvr.md)
 - [CldCvrAvg](docs/Model/CldCvrAvg.md)
 - [CldCvrMax](docs/Model/CldCvrMax.md)
 - [CldCvrMin](docs/Model/CldCvrMin.md)
 - [CountryCode](docs/Model/CountryCode.md)
 - [CountryName](docs/Model/CountryName.md)
 - [Date](docs/Model/Date.md)
 - [DateEnd](docs/Model/DateEnd.md)
 - [DateRangeObj](docs/Model/DateRangeObj.md)
 - [DateStart](docs/Model/DateStart.md)
 - [DewPt](docs/Model/DewPt.md)
 - [DewPtAvg](docs/Model/DewPtAvg.md)
 - [DewPtMax](docs/Model/DewPtMax.md)
 - [DewPtMin](docs/Model/DewPtMin.md)
 - [Distance](docs/Model/Distance.md)
 - [DistancePop](docs/Model/DistancePop.md)
 - [DmaId](docs/Model/DmaId.md)
 - [DmaName](docs/Model/DmaName.md)
 - [DmaObj](docs/Model/DmaObj.md)
 - [ErrorObj](docs/Model/ErrorObj.md)
 - [FeelsLike](docs/Model/FeelsLike.md)
 - [FeelsLikeAvg](docs/Model/FeelsLikeAvg.md)
 - [FeelsLikeMax](docs/Model/FeelsLikeMax.md)
 - [FeelsLikeMin](docs/Model/FeelsLikeMin.md)
 - [FieldListDayObj](docs/Model/FieldListDayObj.md)
 - [FieldListHourObj](docs/Model/FieldListHourObj.md)
 - [Fields](docs/Model/Fields.md)
 - [FreezingRainFlag](docs/Model/FreezingRainFlag.md)
 - [FreezingRainFlagCnt](docs/Model/FreezingRainFlagCnt.md)
 - [Grid](docs/Model/Grid.md)
 - [HeatIndex](docs/Model/HeatIndex.md)
 - [HeatIndexAvg](docs/Model/HeatIndexAvg.md)
 - [HeatIndexMax](docs/Model/HeatIndexMax.md)
 - [HeatIndexMin](docs/Model/HeatIndexMin.md)
 - [HistoryDayArr](docs/Model/HistoryDayArr.md)
 - [HistoryDayObj](docs/Model/HistoryDayObj.md)
 - [HistoryDmaDayObj](docs/Model/HistoryDmaDayObj.md)
 - [HistoryDmaHourObj](docs/Model/HistoryDmaHourObj.md)
 - [HistoryHourArr](docs/Model/HistoryHourArr.md)
 - [HistoryHourObj](docs/Model/HistoryHourObj.md)
 - [HistoryOnpointDayObj](docs/Model/HistoryOnpointDayObj.md)
 - [HistoryOnpointHourObj](docs/Model/HistoryOnpointHourObj.md)
 - [HistoryPointDayObj](docs/Model/HistoryPointDayObj.md)
 - [HistoryPointHourObj](docs/Model/HistoryPointHourObj.md)
 - [HistoryPostcodeDayObj](docs/Model/HistoryPostcodeDayObj.md)
 - [HistoryPostcodeHourObj](docs/Model/HistoryPostcodeHourObj.md)
 - [IcePelletsFlag](docs/Model/IcePelletsFlag.md)
 - [IcePelletsFlagCnt](docs/Model/IcePelletsFlagCnt.md)
 - [Latitude](docs/Model/Latitude.md)
 - [Longitude](docs/Model/Longitude.md)
 - [MslPres](docs/Model/MslPres.md)
 - [MslPresAvg](docs/Model/MslPresAvg.md)
 - [MslPresMax](docs/Model/MslPresMax.md)
 - [MslPresMin](docs/Model/MslPresMin.md)
 - [OnpointId](docs/Model/OnpointId.md)
 - [OnpointObj](docs/Model/OnpointObj.md)
 - [PointObj](docs/Model/PointObj.md)
 - [Population](docs/Model/Population.md)
 - [Postcode](docs/Model/Postcode.md)
 - [PostcodeObj](docs/Model/PostcodeObj.md)
 - [Precip](docs/Model/Precip.md)
 - [PrecipHourCnt](docs/Model/PrecipHourCnt.md)
 - [PresTend](docs/Model/PresTend.md)
 - [PresTendAvg](docs/Model/PresTendAvg.md)
 - [PresTendMax](docs/Model/PresTendMax.md)
 - [PresTendMin](docs/Model/PresTendMin.md)
 - [ProvisionalFlag](docs/Model/ProvisionalFlag.md)
 - [RadSolar](docs/Model/RadSolar.md)
 - [RadSolarAvg](docs/Model/RadSolarAvg.md)
 - [RadSolarMax](docs/Model/RadSolarMax.md)
 - [RadSolarMin](docs/Model/RadSolarMin.md)
 - [RadSolarTot](docs/Model/RadSolarTot.md)
 - [RainFlag](docs/Model/RainFlag.md)
 - [RainFlagCnt](docs/Model/RainFlagCnt.md)
 - [RelHum](docs/Model/RelHum.md)
 - [RelHumAvg](docs/Model/RelHumAvg.md)
 - [RelHumMax](docs/Model/RelHumMax.md)
 - [RelHumMin](docs/Model/RelHumMin.md)
 - [SamplePoints](docs/Model/SamplePoints.md)
 - [SamplePointsInner](docs/Model/SamplePointsInner.md)
 - [SfcPres](docs/Model/SfcPres.md)
 - [SfcPresAvg](docs/Model/SfcPresAvg.md)
 - [SfcPresMax](docs/Model/SfcPresMax.md)
 - [SfcPresMin](docs/Model/SfcPresMin.md)
 - [SnowDepth](docs/Model/SnowDepth.md)
 - [SnowFlag](docs/Model/SnowFlag.md)
 - [SnowFlagCnt](docs/Model/SnowFlagCnt.md)
 - [Snowfall](docs/Model/Snowfall.md)
 - [SnowfallHourCnt](docs/Model/SnowfallHourCnt.md)
 - [SpcHum](docs/Model/SpcHum.md)
 - [SpcHumAvg](docs/Model/SpcHumAvg.md)
 - [SpcHumMax](docs/Model/SpcHumMax.md)
 - [SpcHumMin](docs/Model/SpcHumMin.md)
 - [SubdivCode](docs/Model/SubdivCode.md)
 - [SubdivName](docs/Model/SubdivName.md)
 - [Temp](docs/Model/Temp.md)
 - [TempAvg](docs/Model/TempAvg.md)
 - [TempMax](docs/Model/TempMax.md)
 - [TempMin](docs/Model/TempMin.md)
 - [Timestamp](docs/Model/Timestamp.md)
 - [TimestampEnd](docs/Model/TimestampEnd.md)
 - [TimestampRangeObj](docs/Model/TimestampRangeObj.md)
 - [TimestampStart](docs/Model/TimestampStart.md)
 - [Timezone](docs/Model/Timezone.md)
 - [Vis](docs/Model/Vis.md)
 - [VisAvg](docs/Model/VisAvg.md)
 - [VisMax](docs/Model/VisMax.md)
 - [VisMin](docs/Model/VisMin.md)
 - [WetBulb](docs/Model/WetBulb.md)
 - [WetBulbAvg](docs/Model/WetBulbAvg.md)
 - [WetBulbMax](docs/Model/WetBulbMax.md)
 - [WetBulbMin](docs/Model/WetBulbMin.md)
 - [WindChill](docs/Model/WindChill.md)
 - [WindChillAvg](docs/Model/WindChillAvg.md)
 - [WindChillMax](docs/Model/WindChillMax.md)
 - [WindChillMin](docs/Model/WindChillMin.md)
 - [WindDir](docs/Model/WindDir.md)
 - [WindDir100m](docs/Model/WindDir100m.md)
 - [WindDir100mAvg](docs/Model/WindDir100mAvg.md)
 - [WindDir80m](docs/Model/WindDir80m.md)
 - [WindDir80mAvg](docs/Model/WindDir80mAvg.md)
 - [WindDirAvg](docs/Model/WindDirAvg.md)
 - [WindSpd](docs/Model/WindSpd.md)
 - [WindSpd100m](docs/Model/WindSpd100m.md)
 - [WindSpd100mAvg](docs/Model/WindSpd100mAvg.md)
 - [WindSpd100mMax](docs/Model/WindSpd100mMax.md)
 - [WindSpd100mMin](docs/Model/WindSpd100mMin.md)
 - [WindSpd80m](docs/Model/WindSpd80m.md)
 - [WindSpd80mAvg](docs/Model/WindSpd80mAvg.md)
 - [WindSpd80mMax](docs/Model/WindSpd80mMax.md)
 - [WindSpd80mMin](docs/Model/WindSpd80mMin.md)
 - [WindSpdAvg](docs/Model/WindSpdAvg.md)
 - [WindSpdMax](docs/Model/WindSpdMax.md)
 - [WindSpdMin](docs/Model/WindSpdMin.md)

## Documentation For Authorization


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: X-API-KEY
- **Location**: HTTP header


## Author

support@weathersource.com

